@@ -72,12 +72,16 @@
 #ifndef _TRANS_F_DEFINED_
 #define  _TRANS_F_DEFINED_
 
+#if __cplusplus > 199711L
+#define register      // Deprecated in C++11.
+#endif  // #if __cplusplus > 199711L
+
 /* begin global definition section */
 
-FlintType  OUTP_Identity(FlintType activation);
-FlintType  OUT_Clip_01(FlintType activation);
-FlintType  OUT_Clip_11(FlintType activation);
-FlintType  OUT_Threshold05(FlintType activation);
+FlintType  OUTP_Identity(register FlintType activation);
+FlintType  OUT_Clip_01(register FlintType activation);
+FlintType  OUT_Clip_11(register FlintType activation);
+FlintType  OUT_Threshold05(register FlintType activation);
 FlintType   ACT_Linear(struct Unit *unit_ptr);
 FlintType   ACT_BSBFunction(struct Unit *unit_ptr);
 FlintType   ACT_MinOutPlusWeight(struct Unit *unit_ptr);
